Welcome to the documentation of pyvisco!
========================================

Pyvisco is a Python library that supports the identification of Prony series parameters in Generalized Maxwell models describing linear viscoelastic materials. 

The source code of pyvisco is hosted at `GitHub <https://github.com/NREL/pyvisco/>`_.
The API documentation is hosted at `ReadtheDocs <https://pyvisco.readthedocs.io/>`_.
The web application can be accessed through either `Heroku <https://pyvisco.herokuapp.com/>`_ or `Binder <https://mybinder.org/v2/gh/NREL/pyvisco/HEAD?urlpath=voila%2Frender%2FLinViscoFit.ipynb/>`_.


Contents
========

.. toctree::
   :maxdepth: 3

   readme_link
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`


Dependencies
============

pyvisco depends on the following packages:

.. literalinclude:: ../requirements.txt